==> prestashop_1.0.zip: prestashop_1.0/modules/paypal/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{paypal}prestashop>paypal_ad69e733ebae8d264bccaa38d68830e8'] = 'PayPal';
$_MODULE['<{paypal}prestashop>paypal_5960af4a01187dce25879df9a4c30df1'] = 'Accepter les paiements par PayPal';
$_MODULE['<{paypal}prestashop>paypal_fa214007826415a21a8456e3e09f999d'] = 'Etes-vous sûr de vouloir supprimer vos paramètres ?';
$_MODULE['<{paypal}prestashop>paypal_fea16fa8c8fe3045f2107f66c07270a4'] = 'L\'adresse email Paypal Business est requise.';
$_MODULE['<{paypal}prestashop>paypal_eee1cda3b15829bb68c71304c5028609'] = 'Paypal Business doit être une adresse email';
$_MODULE['<{paypal}prestashop>paypal_f4d1ea475eaa85102e2b4e6d95da84bd'] = 'Confirmation';
$_MODULE['<{paypal}prestashop>paypal_c888438d14855d7d96a2724ee9c306bd'] = 'Configuration mis à jour';
$_MODULE['<{paypal}prestashop>paypal_6357d3551190ec7e79371a8570121d3a'] = 'Il y a';
$_MODULE['<{paypal}prestashop>paypal_4ce81305b7edb043d0a7a5c75cab17d0'] = 'Il y a';
$_MODULE['<{paypal}prestashop>paypal_07213a0161f52846ab198be103b5ab43'] = 'erreurs';
$_MODULE['<{paypal}prestashop>paypal_cb5e100e5a9a3e7f6d1fd97512215282'] = 'erreur';
$_MODULE['<{paypal}prestashop>paypal_1569f6a31ff61f45c5ba13d7cab7e042'] = 'Ce module vous permet d\'accepter les paiements par PayPal.';
$_MODULE['<{paypal}prestashop>paypal_3c4cb777e8df15388c680354569636b6'] = 'Si le client choisi ce mode de paiement, votre compte PayPal sera automatiquement crédité.';
$_MODULE['<{paypal}prestashop>paypal_aaa1b7c0b32bdfdad61e1e2377695a5b'] = 'Vous devez configurer votre compte PayPal avant d\'utiliser ce module.';
$_MODULE['<{paypal}prestashop>paypal_f4f70727dc34561dfde1a3c529b6205c'] = 'Réglages';
$_MODULE['<{paypal}prestashop>paypal_b709ed4067c3bd2272aaf9c3049159d8'] = 'E-mail de votre compte business PayPal';
$_MODULE['<{paypal}prestashop>paypal_7e4ed5efc0f056eb2b36609af35177d3'] = 'Mode Sandbox';
$_MODULE['<{paypal}prestashop>paypal_93cba07454f06a4a960172bbd6e2a435'] = 'Oui';
$_MODULE['<{paypal}prestashop>paypal_bafd7322c6e97d25b6299b5d6fe8920b'] = 'Non';
$_MODULE['<{paypal}prestashop>paypal_386c339d37e737a436499d423a77df0c'] = 'Devise';
$_MODULE['<{paypal}prestashop>paypal_c56aeadf1b4232ca3ef717545133ebb2'] = 'Utiliser la devise par défaut';
$_MODULE['<{paypal}prestashop>paypal_24828b451a72b9711de25e0ced963eaa'] = 'Utiliser la devise du client';
$_MODULE['<{paypal}prestashop>paypal_b17f3f4dcf653a5776792498a9b44d6a'] = 'Mise à jour des réglages';
$_MODULE['<{paypal}prestashop>paypal_a82be0f551b8708bc08eb33cd9ded0cf'] = 'Information';
$_MODULE['<{paypal}prestashop>paypal_8a4a5d8b35abe529250d8167c3035014'] = 'Afin d\'utiliser le module PayPal, vous devez configurer votre compte PayPal. Connectez-vous sur votre compte et suivez ces instructions.';
$_MODULE['<{paypal}prestashop>paypal_efeb369cccbd560588a756610865664c'] = 'Dans';
$_MODULE['<{paypal}prestashop>paypal_93ffd3ee100ec2d93f6dadf45d3d2480'] = 'Profil > Préférences des ventes > Préférences des notifications de paiement instantanés';
$_MODULE['<{paypal}prestashop>paypal_dd7ecd17985702e86fadd19388a55713'] = 'réglez :';
$_MODULE['<{paypal}prestashop>paypal_674a33c037f80fa7108371bb97615916'] = 'Notification de paiement instantanée (IPN)';
$_MODULE['<{paypal}prestashop>paypal_01b6e20344b68835c5ed1ddedf20d531'] = 'à';
$_MODULE['<{paypal}prestashop>paypal_521c36a31c2762741cf0f8890cbe05e3'] = 'On';
$_MODULE['<{paypal}prestashop>paypal_7bfdd7db4889d7a15e2100bb4775abb7'] = 'URL de la Notification de paiement instantanée (IPN)';
$_MODULE['<{paypal}prestashop>paypal_01b6e20344b68835c5ed1ddedf20d531'] = 'à';
$_MODULE['<{paypal}prestashop>paypal_efeb369cccbd560588a756610865664c'] = 'Dans';
$_MODULE['<{paypal}prestashop>paypal_6176bbf80249aa464404925589a31fbe'] = 'Profil > Préférences des ventes > Préférénces du paiement sur le site';
$_MODULE['<{paypal}prestashop>paypal_dd7ecd17985702e86fadd19388a55713'] = 'réglez :';
$_MODULE['<{paypal}prestashop>paypal_6fb9e8044f1f4e90ec2faf0fc6828d8d'] = 'Retour automatique';
$_MODULE['<{paypal}prestashop>paypal_d15305d7a4e34e02489c74a5ef542f36'] = 'Off';
$_MODULE['<{paypal}prestashop>paypal_e126a7f3f1a9cdd4b0b36513a1d84990'] = 'Payment Data Transfer';
$_MODULE['<{paypal}prestashop>paypal_01b6e20344b68835c5ed1ddedf20d531'] = 'à';
$_MODULE['<{paypal}prestashop>paypal_efeb369cccbd560588a756610865664c'] = 'Dans';
$_MODULE['<{paypal}prestashop>paypal_0e4aa2f512e5dd6529b5ddf85bcd5fa3'] = 'Calcul des frais de livraison';
$_MODULE['<{paypal}prestashop>paypal_55e1d666e75135bbb1eb815e7100c68e'] = ', cochez \"Cliquez ici pour autoriser les transactions basées sur frais de ports afin d\'écraser les informations du profil listés à côté\" ';
$_MODULE['<{paypal}prestashop>paypal_8f5d3f72164975d06fd933b097e0cc48'] = 'Votre adresse e-mail PayPal doit être vérifiée';
$_MODULE['<{paypal}prestashop>paypal_ea5ddaff9590d897631f00a7bcb035a2'] = 'Erreur Paypal  : (compte Business invalide ou non défini)';
$_MODULE['<{paypal}prestashop>paypal_e7ac6f09a936201890de4094b1ee4e50'] = 'Erreur Paypal  : (adresse ou client invalide)';
$_MODULE['<{paypal}prestashop>paypal_d89a00d4ba79c176bb0fc17f12d42a18'] = 'La clef PayPal \'mc_gross\' n\'a pas été spécifiée, impossible de contrôler le montant payé.';
$_MODULE['<{paypal}prestashop>paypal_202a2860b19003ce53966a8780bb448b'] = 'La clef PayPal \'payment_status\' n\'a pas été spécifiée, impossible de vérifier la validité du paiement';
$_MODULE['<{paypal}prestashop>paypal_bd0e34e5be6447844e6f262d51f1a9dc'] = 'Paiement :';
$_MODULE['<{paypal}prestashop>paypal_3e2ec97cefea41ef807538dbdc069203'] = 'La clef PayPal \'custom\' n\'a pas été spécifiée, impossible de relayer le panier';
$_MODULE['<{paypal}prestashop>paypal_760c3c2ccfadeee26c80c7b39462cf1d'] = 'La clef PayPal \'txn_id\' n\'a pas été spécifiée, transaction inconnue';
$_MODULE['<{paypal}prestashop>paypal_7faa8448e059fb97d60d4a4b15634d98'] = 'La clef PayPal \'mc_currency\' n\'a pas été spécifiée, devise inconnue';
$_MODULE['<{paypal}prestashop>paypal_e61f52d02b9f52fbe1fd41ed320e29c3'] = 'Panier introuvable';
$_MODULE['<{paypal}prestashop>paypal_0617900b1aff826081d07f5a3e2e7cd0'] = 'La commande a déjà été traitée';
$_MODULE['<{paypal}prestashop>paypal_f5209b3301a46f3057ffbf34d903e205'] = 'ID de la transaction PayPal :';
$_MODULE['<{paypal}prestashop>paypal_660c776a7d0313984bbc112bb97f20bd'] = 'Le paiement PayPal n\'a pas été marqué comme VERIFIE mais :';
$_MODULE['<{paypal}prestashop>paypal_f0dae6a208d7ee9082b902f191bb5bf7'] = 'Impossible de se connecter au serveur PayPal';
$_MODULE['<{paypal}prestashop>paypal_dac2693baa5c5c9a5318609ed81c4f2a'] = 'Payer par PayPal';
$_MODULE['<{paypal}prestashop>paypal_dac2693baa5c5c9a5318609ed81c4f2a'] = 'Payer par PayPal';
$_MODULE['<{paypal}prestashop>paypal_dac2693baa5c5c9a5318609ed81c4f2a'] = 'Payer par PayPal';
$_MODULE['<{paypal}prestashop>paypal_dae3b417a0fc4a49e851ce55d6d49551'] = 'Mon panier';

?>

==> prestashop_1.1.0.1.zip: prestashop_1.1.0.1/modules/paypal/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{paypal}prestashop>paypal_ad69e733ebae8d264bccaa38d68830e8'] = 'PayPal';
$_MODULE['<{paypal}prestashop>paypal_5960af4a01187dce25879df9a4c30df1'] = 'Accepter les paiements par PayPal';
$_MODULE['<{paypal}prestashop>paypal_fa214007826415a21a8456e3e09f999d'] = 'Etes-vous sûr de vouloir supprimer vos paramètres ?';
$_MODULE['<{paypal}prestashop>paypal_fea16fa8c8fe3045f2107f66c07270a4'] = 'L\'adresse email Paypal Business est requise.';
$_MODULE['<{paypal}prestashop>paypal_eee1cda3b15829bb68c71304c5028609'] = 'Paypal Business doit être une adresse email';
$_MODULE['<{paypal}prestashop>paypal_f4d1ea475eaa85102e2b4e6d95da84bd'] = 'Confirmation';
$_MODULE['<{paypal}prestashop>paypal_c888438d14855d7d96a2724ee9c306bd'] = 'Configuration mis à jour';
$_MODULE['<{paypal}prestashop>paypal_6357d3551190ec7e79371a8570121d3a'] = 'Il y a';
$_MODULE['<{paypal}prestashop>paypal_4ce81305b7edb043d0a7a5c75cab17d0'] = 'Il y a';
$_MODULE['<{paypal}prestashop>paypal_07213a0161f52846ab198be103b5ab43'] = 'erreurs';
$_MODULE['<{paypal}prestashop>paypal_cb5e100e5a9a3e7f6d1fd97512215282'] = 'erreur';
$_MODULE['<{paypal}prestashop>paypal_1569f6a31ff61f45c5ba13d7cab7e042'] = 'Ce module vous permet d\'accepter les paiements par PayPal.';
$_MODULE['<{paypal}prestashop>paypal_3c4cb777e8df15388c680354569636b6'] = 'Si le client choisit ce mode de paiement, votre compte PayPal sera automatiquement crédité.';
$_MODULE['<{paypal}prestashop>paypal_aaa1b7c0b32bdfdad61e1e2377695a5b'] = 'Vous devez configurer votre compte PayPal avant d\'utiliser ce module.';
$_MODULE['<{paypal}prestashop>paypal_f4f70727dc34561dfde1a3c529b6205c'] = 'Réglages';
$_MODULE['<{paypal}prestashop>paypal_b709ed4067c3bd2272aaf9c3049159d8'] = 'E-mail de votre compte business PayPal';
$_MODULE['<{paypal}prestashop>paypal_7e4ed5efc0f056eb2b36609af35177d3'] = 'Mode Sandbox';
$_MODULE['<{paypal}prestashop>paypal_93cba07454f06a4a960172bbd6e2a435'] = 'Oui';
$_MODULE['<{paypal}prestashop>paypal_bafd7322c6e97d25b6299b5d6fe8920b'] = 'Non';
$_MODULE['<{paypal}prestashop>paypal_b17f3f4dcf653a5776792498a9b44d6a'] = 'Mise à jour des réglages';
$_MODULE['<{paypal}prestashop>paypal_a82be0f551b8708bc08eb33cd9ded0cf'] = 'Information';
$_MODULE['<{paypal}prestashop>paypal_8a4a5d8b35abe529250d8167c3035014'] = 'Afin d\'utiliser le module PayPal, vous devez configurer votre compte PayPal. Connectez-vous sur votre compte et suivez ces instructions.';
$_MODULE['<{paypal}prestashop>paypal_efeb369cccbd560588a756610865664c'] = 'Dans';
$_MODULE['<{paypal}prestashop>paypal_93ffd3ee100ec2d93f6dadf45d3d2480'] = 'Profil > Préférences des ventes > Préférences des notifications de paiement instantanés';
$_MODULE['<{paypal}prestashop>paypal_dd7ecd17985702e86fadd19388a55713'] = 'réglez :';
$_MODULE['<{paypal}prestashop>paypal_674a33c037f80fa7108371bb97615916'] = 'Notification de paiement instantanée (IPN)';
$_MODULE['<{paypal}prestashop>paypal_01b6e20344b68835c5ed1ddedf20d531'] = 'à';
$_MODULE['<{paypal}prestashop>paypal_521c36a31c2762741cf0f8890cbe05e3'] = 'On';
$_MODULE['<{paypal}prestashop>paypal_7bfdd7db4889d7a15e2100bb4775abb7'] = 'URL de la Notification de paiement instantanée (IPN)';
$_MODULE['<{paypal}prestashop>paypal_01b6e20344b68835c5ed1ddedf20d531'] = 'à';
$_MODULE['<{paypal}prestashop>paypal_efeb369cccbd560588a756610865664c'] = 'Dans';
$_MODULE['<{paypal}prestashop>paypal_6176bbf80249aa464404925589a31fbe'] = 'Profil > Préférences des ventes > Préférénces du paiement sur le site';
$_MODULE['<{paypal}prestashop>paypal_dd7ecd17985702e86fadd19388a55713'] = 'réglez :';
$_MODULE['<{paypal}prestashop>paypal_6fb9e8044f1f4e90ec2faf0fc6828d8d'] = 'Retour automatique';
$_MODULE['<{paypal}prestashop>paypal_d15305d7a4e34e02489c74a5ef542f36'] = 'Off';
$_MODULE['<{paypal}prestashop>paypal_e126a7f3f1a9cdd4b0b36513a1d84990'] = 'Payment Data Transfer';
$_MODULE['<{paypal}prestashop>paypal_01b6e20344b68835c5ed1ddedf20d531'] = 'à';
$_MODULE['<{paypal}prestashop>paypal_efeb369cccbd560588a756610865664c'] = 'Dans';
$_MODULE['<{paypal}prestashop>paypal_0e4aa2f512e5dd6529b5ddf85bcd5fa3'] = 'Calcul des frais de livraison';
$_MODULE['<{paypal}prestashop>paypal_55e1d666e75135bbb1eb815e7100c68e'] = ', cochez \"Cliquez ici pour autoriser les transactions basées sur frais de ports afin d\'écraser les informations du profil listés à côté\" ';
$_MODULE['<{paypal}prestashop>paypal_8f5d3f72164975d06fd933b097e0cc48'] = 'Votre adresse e-mail PayPal doit être vérifiée';
$_MODULE['<{paypal}prestashop>paypal_ea5ddaff9590d897631f00a7bcb035a2'] = 'Erreur Paypal  : (compte Business invalide ou non défini)';
$_MODULE['<{paypal}prestashop>paypal_e7ac6f09a936201890de4094b1ee4e50'] = 'Erreur Paypal  : (adresse ou client invalide)';
$_MODULE['<{paypal}prestashop>paypal_d89a00d4ba79c176bb0fc17f12d42a18'] = 'La clef PayPal \'mc_gross\' n\'a pas été spécifiée, impossible de contrôler le montant payé.';
$_MODULE['<{paypal}prestashop>paypal_202a2860b19003ce53966a8780bb448b'] = 'La clef PayPal \'payment_status\' n\'a pas été spécifiée, impossible de vérifier la validité du paiement';
$_MODULE['<{paypal}prestashop>paypal_bd0e34e5be6447844e6f262d51f1a9dc'] = 'Paiement :';
$_MODULE['<{paypal}prestashop>paypal_3e2ec97cefea41ef807538dbdc069203'] = 'La clef PayPal \'custom\' n\'a pas été spécifiée, impossible de relayer le panier';
$_MODULE['<{paypal}prestashop>paypal_760c3c2ccfadeee26c80c7b39462cf1d'] = 'La clef PayPal \'txn_id\' n\'a pas été spécifiée, transaction inconnue';
$_MODULE['<{paypal}prestashop>paypal_7faa8448e059fb97d60d4a4b15634d98'] = 'La clef PayPal \'mc_currency\' n\'a pas été spécifiée, devise inconnue';
$_MODULE['<{paypal}prestashop>paypal_e61f52d02b9f52fbe1fd41ed320e29c3'] = 'Panier introuvable';
$_MODULE['<{paypal}prestashop>paypal_0617900b1aff826081d07f5a3e2e7cd0'] = 'La commande a déjà été traitée';
$_MODULE['<{paypal}prestashop>paypal_f5209b3301a46f3057ffbf34d903e205'] = 'ID de la transaction PayPal :';
$_MODULE['<{paypal}prestashop>paypal_7b19e875ff64b09d80ee05dcc84b9975'] = 'La transaction PayPal ne peut pas être VERIFIEE.';
$_MODULE['<{paypal}prestashop>paypal_20dfea1a472e5be3f15f6b5f36ca335c'] = 'Problèmes lors de la tentative de connexion au serveur PayPal.';
$_MODULE['<{paypal}prestashop>paypal_76ee8dc73701e846f7bccdf98dae079b'] = 'Aucun protocole de communication disponible.';
$_MODULE['<{paypal}prestashop>paypal_8358ec19f397d4cdd632688d4f79e535'] = 'Echec de la vérification (protocole fsockopen). Retour :';
$_MODULE['<{paypal}prestashop>paypal_eca77e208634d52703b07672abbf16ec'] = 'Echec de la vérification (protocole cURL). Retour :';
$_MODULE['<{paypal}prestashop>paypal_f7799c2ded739cf3c3e9babffc5f315b'] = 'La connection via le protocole cURL a échoué.';
$_MODULE['<{paypal}prestashop>paypal_dac2693baa5c5c9a5318609ed81c4f2a'] = 'Payer par PayPal';
$_MODULE['<{paypal}prestashop>paypal_dac2693baa5c5c9a5318609ed81c4f2a'] = 'Payer par PayPal';
$_MODULE['<{paypal}prestashop>paypal_dac2693baa5c5c9a5318609ed81c4f2a'] = 'Payer par PayPal';
$_MODULE['<{paypal}prestashop>paypal_dae3b417a0fc4a49e851ce55d6d49551'] = 'Mon panier';

?>
